# Bureau Voting Model Project
# Matching Method and Graphics Code
# Nick Davis and Joshua Potter
# August 2014

###################################
# FIRST, ADDITIONAL STATA RECODES #
###################################

gen leftvote1 = 1 if rile<0
replace leftvote1 = 0 if rile > 0
replace leftvote1 = 0 if rile == 0
replace leftvote1 = . if rile == .

# this is currently my favorite outcome variable 
gen leftvote2 = 0
replace leftvote2 = 1 if parfam == 10
replace leftvote2 = 1 if parfam == 20
replace leftvote2 = 1 if parfam == 30
replace leftvote2 = 1 if parfam == 40
replace leftvote2 = . if parfam == .
rename leftvote2 leftvote

gen leftper = (per504+per506)-per303
summarize leftper  
# I think I want to stay with leftper in its continuous form rather than discretize it

gen treat1 = 1 if publicemploy == 1
replace treat1 = 0 if publicemploy == 0
replace treat1 = . if publicemploy ==. 
gen treat2 = 1 if altpubemploy == 1
replace treat2 = 0 if altpubemploy == 0
replace treat2 = . if altpubemploy ==. 

# load the package you need to read .dta files
library(foreign)

# load packages to conduct analysis
library(MASS)
library(MatchIt)
library(boot)
library(zoo)
library(sandwich)
library(Zelig)

##################
# MODULE 1 TESTS #
##################

# read in data from Module 1 Stata file
bvm.data1<-read.dta("~/Dropbox/Bureau Voting/Data and Analysis/dta files for Modules (recodes)/Module 1 (recodes).dta")
summary(bvm.data)

####################
# VARIABLE RECODES #
####################

# subset identifiers
country<-bvm.data1$countryyear
district<-bvm.data1$districtid

# controls for matching
age<-bvm.data1$generationcohort
income<-bvm.data1$hhincome
gender<-bvm.data1$male
education<-bvm.data1$educ3
religion<-bvm.data1$religiosity
ideology<-bvm.data1$ideo3
union<-bvm.data1$unionmember
married<-bvm.data1$married 

# treatment
treatment<-bvm.data1$treat1

# outcome
left1<-bvm.data1$leftvote2 # based on parfam
left2<-bvm.data1$leftper # based on govt expansion rhetoric

# create data frame to feed to MatchIt
n.frame<-cbind(country, district, age, income, gender, education, ideology, union, treatment, left1, left2)
myframe<-as.data.frame(n.frame)
summary(myframe)

# create country-year subsets
AUS_1996data<-subset(myframe, country=="AUS_1996")
CAN_1997data<-subset(myframe, country=="CAN_1997")
CHE_1999data<-subset(myframe, country=="CHE_1999")
CZE_1996data<-subset(myframe, country=="CZE_1996")
DEU_1998data<-subset(myframe, country=="DEU_1998")
DNK_1998data<-subset(myframe, country=="DNK_1998")
ESP_1996data<-subset(myframe, country=="ESP_1996")
ESP_2000data<-subset(myframe, country=="ESP_2000")
GBR_1997data<-subset(myframe, country=="GBR_1997")
HUN_1998data<-subset(myframe, country=="HUN_1998")
ISL_1999data<-subset(myframe, country=="ISL_1999")
ISR_1996data<-subset(myframe, country=="ISR_1996")
JPN_1996data<-subset(myframe, country=="JPN_1996")
KOR_2000data<-subset(myframe, country=="KOR_2000")
MEX_1997data<-subset(myframe, country=="MEX_1997")
NLD_1998data<-subset(myframe, country=="NLD_1998")
NOR_1997data<-subset(myframe, country=="NOR_1997")
NZL_1996data<-subset(myframe, country=="NZL_1996")
PER_2000data<-subset(myframe, country=="PER_2000")
PER_2001data<-subset(myframe, country=="PER_2001")
POL_1997data<-subset(myframe, country=="POL_1997")
PRT_2002data<-subset(myframe, country=="PRT_2002")
ROU_1996data<-subset(myframe, country=="ROU_1996")
SVN_1996data<-subset(myframe, country=="SVN_1996")
SWE_1998data<-subset(myframe, country=="SWE_1998")
UKR_1998data<-subset(myframe, country=="UKR_1998")
USA_1996data<-subset(myframe, country=="USA_1996")


#####################
# MATCHING ANALYSIS #
#####################

AUS_1996data<-na.omit(AUS_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =AUS_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CAN_1997data<-na.omit(CAN_1997data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =CAN_1997data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CHE_1999data<-na.omit(CHE_1999data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =CHE_1999data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CZE_1996data<-na.omit(CZE_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =CZE_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

#### THIS SIMULATION DOESN'T CONVERGE
#### THIS SIMULATION DOESN'T CONVERGE
DEU_1998data<-na.omit(DEU_1998data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =DEU_1998data, method="logit")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)


DNK_1998data<-na.omit(DNK_1998data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =DNK_1998data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ESP_1996data<-na.omit(ESP_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =ESP_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ESP_2000data<-na.omit(ESP_2000data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =ESP_2000data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

#### THIS SIMULATION DOESN'T CONVERGE
#### THIS SIMULATION DOESN'T CONVERGE
GBR_1997data<-na.omit(GBR_1997data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =GBR_1997data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
summary(z.out)
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

HUN_1998data<-na.omit(HUN_1998data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =HUN_1998data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ISL_1999data<-na.omit(ISL_1999data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =ISL_1999data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

### NO DATA IN HERE, SOME ITEM MUST BE MISSING
### NO DATA IN HERE, SOME ITEM MUST BE MISSING
ISR_1996data<-na.omit(ISR_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =ISR_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

### NO DATA IN HERE, SOME ITEM MUST BE MISSING
### NO DATA IN HERE, SOME ITEM MUST BE MISSING
JPN_1996data<-na.omit(JPN_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =JPN_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

#### THIS SIMULATION DOESN'T CONVERGE
#### THIS SIMULATION DOESN'T CONVERGE
KOR_2000data<-na.omit(KOR_2000data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =KOR_2000data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
summary(z.out)
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

MEX_1997data<-na.omit(MEX_1997data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =MEX_1997data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

### NO DATA IN HERE, SOME ITEM MUST BE MISSING
### NO DATA IN HERE, SOME ITEM MUST BE MISSING
NLD_1998data<-na.omit(NLD_1998data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =NLD_1998data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NOR_1997data<-na.omit(NOR_1997data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =NOR_1997data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NZL_1996data<-na.omit(NZL_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =NZL_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

### NO DATA IN HERE, SOME ITEM MUST BE MISSING
### NO DATA IN HERE, SOME ITEM MUST BE MISSING
PER_2000data<-na.omit(PER_2000data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =PER_2000data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

### NO DATA IN HERE, SOME ITEM MUST BE MISSING
### NO DATA IN HERE, SOME ITEM MUST BE MISSING
PER_2001data<-na.omit(PER_2001data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =PER_2001data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

POL_1997data<-na.omit(POL_1997data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =POL_1997data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

#### THIS SIMULATION DOESN'T CONVERGE
#### THIS SIMULATION DOESN'T CONVERGE
PRT_2002data<-na.omit(PRT_2002data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =PRT_2002data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

#### THIS SIMULATION DOESN'T CONVERGE
#### THIS SIMULATION DOESN'T CONVERGE
ROU_1996data<-na.omit(ROU_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =ROU_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SVN_1996data<-na.omit(SVN_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =SVN_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SWE_1998data<-na.omit(SWE_1998data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =SWE_1998data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

#### THIS SIMULATION DOESN'T CONVERGE
#### THIS SIMULATION DOESN'T CONVERGE
UKR_1998data<-na.omit(UKR_1998data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =UKR_1998data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

USA_1996data<-na.omit(USA_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender , data =USA_1996data, method="exact")
summary(m.out)
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + income + education + ideology + gender , data = m.data, model="logit")
summary(z.out)
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)



















#################################
## Some prelim discarded stuff ##
##################################

# match Spain
ESP_1996data<-na.omit(ESP_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender + religion, data = ESP_1996data, method = "exact")
summary(m.out)
m.data<-match.data(m.out)

# model
z.out<-zelig(left2 ~ treatment + income + education + ideology + gender + religion, data = m.data, model="logit")
summary(z.out)

# predicted values
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)
plot(s.out)


# match United Kingdom
GBR_1997data<-na.omit(GBR_1997data)
m.out<-matchit(treatment ~ income + education + ideology + gender, data = GBR_1997data, method = "exact")
summary(m.out)
m.data<-match.data(m.out)

# match United States
USA_1996data<-na.omit(USA_1996data)
m.out<-matchit(treatment ~ income + education + ideology + gender, data = USA_1996data, method = "exact")
summary(m.out)
m.data<-match.data(m.out)

# match Norway
NOR_1997data<-na.omit(NOR_1997data)
m.out<-matchit(treatment ~ income + education + ideology + gender + religion, data = NOR_1997data, method = "exact")
summary(m.out)
m.data<-match.data(m.out)

# match Mexico 
MEX_1997data<-na.omit(MEX_1997data)
m.out<-matchit(treatment ~ income + education + ideology + gender + religion, data = MEX_1997data, method = "exact")
summary(m.out)
m.data<-match.data(m.out)


# model
z.out<-zelig(left2 ~ treatment + income + education + ideology + gender + religion, data = m.data, model="logit")
summary(z.out)

# predicted values
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)
plot(s.out)

# average treatment effect
z.out2<-zelig(left2 ~ income + education + ideology + gender, data=match.data(m.out, "treat"), model="logit")
x.out2<-setx(z.out2, data=match.data(m.out, "control"))
s.out2<-sim(z.out2, x=x.out2)
summary(s.out2)
