#####################################
#####################################
# Bureau Voting Model Project #######
# Matching Method and Graphics Code #
# Nick Davis and Joshua Potter ######
# September 2014 ####################
#####################################
#####################################

# load the package you need to read .dta files
library(foreign)

# load packages to conduct analysis
library(MASS)
library(MatchIt)
library(boot)
library(zoo)
library(sandwich)
library(Zelig)

##################
# MODULE 1 TESTS #
##################

# read in data from Module 1 Stata file
bvm.data1<-read.dta("~/Dropbox/Bureau Voting/Data and Analysis/dta files for Modules (recodes)/Module 1 (recodes).dta")
summary(bvm.data1)

####################
# VARIABLE RECODES #
####################

# subset identifiers
country<-bvm.data1$countryyear
district<-bvm.data1$districtid

# controls for matching
age<-bvm.data1$generationcohort
income<-bvm.data1$hhincome
gender<-bvm.data1$male
education<-bvm.data1$educ3
religion<-bvm.data1$religiosity
ideology<-bvm.data1$ideo3
union<-bvm.data1$unionmember
married<-bvm.data1$married 

# treatment
treatment<-bvm.data1$treat1

# outcome
left1<-bvm.data1$leftvote2 # based on parfam
left2<-bvm.data1$leftper # based on govt expansion rhetoric


######################
# MATCHIT DATA FRAME #
######################

n.frame<-cbind(country, district, age, income, gender, education, ideology, union, treatment, left1, left2)
myframe<-as.data.frame(n.frame)
summary(myframe)

AUS_1996data<-subset(myframe, country=="AUS_1996")
CAN_1997data<-subset(myframe, country=="CAN_1997")
CHE_1999data<-subset(myframe, country=="CHE_1999")
CZE_1996data<-subset(myframe, country=="CZE_1996")
DEU_1998data<-subset(myframe, country=="DEU_1998")
DNK_1998data<-subset(myframe, country=="DNK_1998")
ESP_1996data<-subset(myframe, country=="ESP_1996")
ESP_2000data<-subset(myframe, country=="ESP_2000")
GBR_1997data<-subset(myframe, country=="GBR_1997")
HUN_1998data<-subset(myframe, country=="HUN_1998")
ISL_1999data<-subset(myframe, country=="ISL_1999")
ISR_1996data<-subset(myframe, country=="ISR_1996")
JPN_1996data<-subset(myframe, country=="JPN_1996")
KOR_2000data<-subset(myframe, country=="KOR_2000")
MEX_1997data<-subset(myframe, country=="MEX_1997")
NLD_1998data<-subset(myframe, country=="NLD_1998")
NOR_1997data<-subset(myframe, country=="NOR_1997")
NZL_1996data<-subset(myframe, country=="NZL_1996")
PER_2000data<-subset(myframe, country=="PER_2000")
PER_2001data<-subset(myframe, country=="PER_2001")
POL_1997data<-subset(myframe, country=="POL_1997")
PRT_2002data<-subset(myframe, country=="PRT_2002")
ROU_1996data<-subset(myframe, country=="ROU_1996")
SVN_1996data<-subset(myframe, country=="SVN_1996")
SWE_1998data<-subset(myframe, country=="SWE_1998")
UKR_1998data<-subset(myframe, country=="UKR_1998")
USA_1996data<-subset(myframe, country=="USA_1996")


#####################
# MATCHING ANALYSIS #
#####################

### AUSTRALIA

# looks like all covariates are populated with values
summary(AUS_1996data) 

# we lose 66 "treated" individuals 
AUS_1996data<-na.omit(AUS_1996data)
m.out<-matchit(treatment ~ age + income + gender + education + ideology + union, data =AUS_1996data, method="exact")
summary(m.out)

# run the analysis on expansion rhetoric
m.data<-match.data(m.out)
z.out<-zelig(as.numeric(left2) ~ treatment + age + income + gender + education + ideology + union , data = m.data, model="ls")

# check out the treatment effect
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

# run the analysis on leftist vote choice
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + age + income + gender + education + ideology + union , data = m.data, model="logit")

# check out the treatment effect
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)


### SPAIN .... there are problems here with missingness 

# looks like all covariates are populated with values
summary(ESP_2000data) 

# we lose 66 "treated" individuals 
ESP_2000data<-na.omit(ESP_2000data)
m.out<-matchit(treatment ~ age + income + gender + education + ideology + union, data =ESP_2000data, method="exact")
summary(m.out)

# run the analysis on expansion rhetoric
m.data<-match.data(m.out)
z.out<-zelig(as.numeric(left2) ~ treatment + age + income + gender + education + ideology + union , data = m.data, model="ls")

# check out the treatment effect
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

# run the analysis on leftist vote choice
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + age + income + gender + education + ideology + union , data = m.data, model="logit")

# check out the treatment effect
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)



