#####################################
#####################################
# Bureau Voting Model Project #######
# Matching Method and Graphics Code #
# Nick Davis and Joshua Potter ######
# October 2014 ######################
#####################################
#####################################

# load the package you need to read .dta files
library(foreign)

# load packages to conduct analysis
library(MASS)
library(MatchIt)
library(boot)
library(zoo)
library(sandwich)
library(Zelig)


###################################
# FIRST, ADDITIONAL STATA RECODES #
###################################

# party-family outcome variable 
gen leftvote2 = 0
replace leftvote2 = 1 if parfam == 10
replace leftvote2 = 1 if parfam == 20
replace leftvote2 = 1 if parfam == 30
replace leftvote2 = 1 if parfam == 40
replace leftvote2 = . if parfam == .
rename leftvote2 leftvote

# government expansion outcome variable 
gen leftper = (per504+per506)-per303
rename leftper expansion

# treatment
gen treat = 1 if publicemploy == 1
replace treat = 0 if publicemploy == 0
replace treat = . if publicemploy ==. 

# country-election identifiers 
gen cnty = countryyear 

# union membership
gen union = 1 if unionmember == 1
replace union = 0 if unionmember == 0
replace union = . if unionmember == .

# age
rename age ageyear
gen age = . 
replace age = 0 if generationcohort == 0
replace age = 1 if generationcohort == 1
replace age = 2 if generationcohort == 2
replace age = 3 if generationcohort == 3

# income
gen income = . 
replace income = 1 if hhincome == 1
replace income = 2 if hhincome == 2
replace income = 3 if hhincome == 3
replace income = 4 if hhincome == 4
replace income = 5 if hhincome == 5

# gender
rename male gender
gen male = .
replace male = 1 if gender == 1
replace male = 0 if gender == 0

# education
rename education school
gen education = . 
replace education = 0 if educ3 == 0
replace education = 1 if educ3 == 1
replace education = 2 if educ3 == 2

# ideology 
gen ideology = . 
replace ideology = 0 if ideo3 == 0
replace ideology = 1 if ideo3 == 1
replace ideology = 2 if ideo3 == 2


####################################
# AGGREGATED MODULES 1,2,3,4 TESTS #
####################################

# read in data from Nick's merged Stata file
bvm.data<-read.dta("~/Dropbox/Bureau Voting/Data and Analysis/dta files for Modules (recodes)/MERGED CSES (modules 1 - 4).dta")
summary(bvm.data)
attach(bvm.data)

n.frame<-cbind(cnty, leftvote, expansion, treat, income, education, ideology, age)
bvm <- as.data.frame(n.frame)
summary(bvm)

###################################################
# TESTING VOTE FOR LEFTIST PARTIES (PARTY FAMILY) #
###################################################

ALB_2005data<-subset(bvm, cnty=="ALB_2005")
ALB_2005data<-na.omit(ALB_2005data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ALB_2005data, method="exact")
m.data<-match.data(m.out)
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

z.out<-zelig(as.numeric(expansion) ~ treat + income + education + age + ideology, data = m.data, model="ls")

AUS_1996data<-subset(bvm, cnty=="AUS_1996")
AUS_1996data<-na.omit(AUS_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =AUS_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

AUS_2004data<-subset(bvm, cnty=="AUS_2004")
AUS_2004data<-na.omit(AUS_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =AUS_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

AUS_2007data<-subset(bvm, cnty=="AUS_2007")
AUS_2007data<-na.omit(AUS_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =AUS_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

AUT_2008data<-subset(bvm, cnty=="AUT_2008")
AUT_2008data<-na.omit(AUT_2008data)
m.out<-matchit(treat ~ income + education + age + ideology, data =AUT_2008data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

BEL_2003data<-subset(bvm, cnty=="BEL_2003")
BEL_2003data<-na.omit(BEL_2003data)
m.out<-matchit(treat ~ income + education + age + ideology, data =BEL_2003data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

BGR_2001data<-subset(bvm, cnty=="BGR_2001")
BGR_2001data<-na.omit(BGR_2001data)
m.out<-matchit(treat ~ income + education + age + ideology, data =BGR_2001data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CAN_1997data<-subset(bvm, cnty=="CAN_1997")
CAN_1997data<-na.omit(CAN_1997data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CAN_1997data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CAN_2004data<-subset(bvm, cnty=="CAN_2004")
CAN_2004data<-na.omit(CAN_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CAN_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CAN_2008data<-subset(bvm, cnty=="CAN_2008")
CAN_2008data<-na.omit(CAN_2008data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CAN_2008data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CHE_1999data<-subset(bvm, cnty=="CHE_1999")
CHE_1999data<-na.omit(CHE_1999data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CHE_1999data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CHE_2003data<-subset(bvm, cnty=="CHE_2003")
CHE_2003data<-na.omit(CHE_2003data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CHE_2003data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CHE_2007data<-subset(bvm, cnty=="CHE_2007")
CHE_2007data<-na.omit(CHE_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CHE_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CHE_2011data<-subset(bvm, cnty=="CHE_2011")
CHE_2011data<-na.omit(CHE_2011data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CHE_2011data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CHL_2005data<-subset(bvm, cnty=="CHL_2005")
CHL_2005data<-na.omit(CHL_2005data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CHL_2005data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CZE_1996data<-subset(bvm, cnty=="CZE_1996")
CZE_1996data<-na.omit(CZE_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CZE_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CZE_2002data<-subset(bvm, cnty=="CZE_2002")
CZE_2002data<-na.omit(CZE_2002data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CZE_2002data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CZE_2006data<-subset(bvm, cnty=="CZE_2006")
CZE_2006data<-na.omit(CZE_2006data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CZE_2006data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

CZE_2010data<-subset(bvm, cnty=="CZE_2010")
CZE_2010data<-na.omit(CZE_2010data)
m.out<-matchit(treat ~ income + education + age + ideology, data =CZE_2010data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

DEU_1998data<-subset(bvm, cnty=="DEU_1998")
DEU_1998data<-na.omit(DEU_1998data)
m.out<-matchit(treat ~ income + education + age + ideology, data =DEU_1998data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

DEU_2005data<-subset(bvm, cnty=="DEU_2005")
DEU_2005data<-na.omit(DEU_2005data)
m.out<-matchit(treat ~ income + education + age + ideology, data =DEU_2005data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

DEU_2009data<-subset(bvm, cnty=="DEU_2009")
DEU_2009data<-na.omit(DEU_2009data)
m.out<-matchit(treat ~ income + education + age + ideology, data =DEU_2009data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

DNK_1998data<-subset(bvm, cnty=="DNK_1998")
DNK_1998data<-na.omit(DNK_1998data)
m.out<-matchit(treat ~ income + education + age + ideology, data =DNK_1998data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

DNK_2001data<-subset(bvm, cnty=="DNK_2001")
DNK_2001data<-na.omit(DNK_2001data)
m.out<-matchit(treat ~ income + education + age + ideology, data =DNK_2001data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

DNK_2007data<-subset(bvm, cnty=="DNK_2007")
DNK_2007data<-na.omit(DNK_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =DNK_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ESP_1996data<-subset(bvm, cnty=="ESP_1996")
ESP_1996data<-na.omit(ESP_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ESP_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ESP_2000data<-subset(bvm, cnty=="ESP_2000")
ESP_2000data<-na.omit(ESP_2000data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ESP_2000data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ESP_2004data<-subset(bvm, cnty=="ESP_2004")
ESP_2004data<-na.omit(ESP_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ESP_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ESP_2008data<-subset(bvm, cnty=="ESP_2008")
ESP_2008data<-na.omit(ESP_2008data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ESP_2008data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

EST_2011data<-subset(bvm, cnty=="EST_2011")
EST_2011data<-na.omit(EST_2011data)
m.out<-matchit(treat ~ income + education + age + ideology, data =EST_2011data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

FIN_2003data<-subset(bvm, cnty=="FIN_2003")
FIN_2003data<-na.omit(FIN_2003data)
m.out<-matchit(treat ~ income + education + age + ideology, data =FIN_2003data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

FIN_2007data<-subset(bvm, cnty=="FIN_2007")
FIN_2007data<-na.omit(FIN_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =FIN_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

FIN_2011data<-subset(bvm, cnty=="FIN_2011")
FIN_2011data<-na.omit(FIN_2011data)
m.out<-matchit(treat ~ income + education + age + ideology, data =FIN_2011data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

FRA_2007data<-subset(bvm, cnty=="FRA_2007")
FRA_2007data<-na.omit(FRA_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =FRA_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

GBR_1997data<-subset(bvm, cnty=="GBR_1997")
GBR_1997data<-na.omit(GBR_1997data)
m.out<-matchit(treat ~ income + education + age + ideology, data =GBR_1997data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

GBR_2005data<-subset(bvm, cnty=="GBR_2005")
GBR_2005data<-na.omit(GBR_2005data)
m.out<-matchit(treat ~ income + education + age + ideology, data =GBR_2005data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

HUN_1998data<-subset(bvm, cnty=="HUN_1998")
HUN_1998data<-na.omit(HUN_1998data)
m.out<-matchit(treat ~ income + education + age + ideology, data =HUN_1998data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

HUN_2002data<-subset(bvm, cnty=="HUN_2002")
HUN_2002data <-na.omit(HUN_2002data)
m.out<-matchit(treat ~ income + education + age + ideology, data =HUN_2002data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

IRL_2002data<-subset(bvm, cnty=="IRL_2002")
IRL_2002data <-na.omit(IRL_2002data)
m.out<-matchit(treat ~ income + education + age + ideology, data =IRL_2002data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

IRL_2007data<-subset(bvm, cnty=="IRL_2007")
IRL_2007data <-na.omit(IRL_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =IRL_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

IRL_2011data<-subset(bvm, cnty=="IRL_2011")
IRL_2011data <-na.omit(IRL_2011data)
m.out<-matchit(treat ~ income + education + age + ideology, data =IRL_2011data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ISL_1999data<-subset(bvm, cnty=="ISL_1999")
ISL_1999data <-na.omit(ISL_1999data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ISL_1999data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ISL_2007data<-subset(bvm, cnty=="ISL_2007")
ISL_2007data <-na.omit(ISL_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ISL_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ISL_2009data<-subset(bvm, cnty=="ISL_2009")
ISL_2009data <-na.omit(ISL_2009data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ISL_2009data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ISR_1996data<-subset(bvm, cnty=="ISR_1996")
ISR_1996data <-na.omit(ISR_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ISR_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ITA_2006data<-subset(bvm, cnty=="ITA_2006")
ITA_2006data <-na.omit(ITA_2006data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ITA_2006data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

JPN_1996data<-subset(bvm, cnty=="JPN_1996")
JPN_1996data <-na.omit(JPN_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =JPN_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

JPN_2004data<-subset(bvm, cnty=="JPN_2004")
JPN_2004data <-na.omit(JPN_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =JPN_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

JPN_2007data<-subset(bvm, cnty=="JPN_2007")
JPN_2007data <-na.omit(JPN_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =JPN_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

KOR_2000data<-subset(bvm, cnty=="KOR_2000")
KOR_2000data <-na.omit(KOR_2000data)
m.out<-matchit(treat ~ income + education + age + ideology, data =KOR_2000data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

KOR_2004data<-subset(bvm, cnty=="KOR_2004")
KOR_2004data <-na.omit(KOR_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =KOR_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

KOR_2008data<-subset(bvm, cnty=="KOR_2008")
KOR_2008data <-na.omit(KOR_2008data)
m.out<-matchit(treat ~ income + education + age + ideology, data =KOR_2008data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

MEX_1997data<-subset(bvm, cnty=="MEX_1997")
MEX_1997data <-na.omit(MEX_1997data)
m.out<-matchit(treat ~ income + education + age + ideology, data =MEX_1997data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

MEX_2003data<-subset(bvm, cnty=="MEX_2003")
MEX_2003data <-na.omit(MEX_2003data)
m.out<-matchit(treat ~ income + education + age + ideology, data =MEX_2003data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

MEX_2006data<-subset(bvm, cnty=="MEX_2006")
MEX_2006data <-na.omit(MEX_2006data)
m.out<-matchit(treat ~ income + education + age + ideology, data =MEX_2006data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

MEX_2009data<-subset(bvm, cnty=="MEX_2009")
MEX_2009data <-na.omit(MEX_2009data)
m.out<-matchit(treat ~ income + education + age + ideology, data =MEX_2009data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NLD_1998data<-subset(bvm, cnty=="NLD_1998")
NLD_1998data <-na.omit(NLD_1998data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NLD_1998data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NLD_2002data<-subset(bvm, cnty=="NLD_2002")
NLD_2002data <-na.omit(NLD_2002data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NLD_2002data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NLD_2006data<-subset(bvm, cnty=="NLD_2006")
NLD_2006data <-na.omit(NLD_2006data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NLD_2006data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NLD_2010data<-subset(bvm, cnty=="NLD_2010")
NLD_2010data <-na.omit(NLD_2010data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NLD_2010data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NOR_1997data<-subset(bvm, cnty=="NOR_1997")
NOR_1997data <-na.omit(NOR_1997data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NOR_1997data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NOR_2001data<-subset(bvm, cnty=="NOR_2001")
NOR_2001data <-na.omit(NOR_2001data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NOR_2001data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NOR_2005data<-subset(bvm, cnty=="NOR_2005")
NOR_2005data <-na.omit(NOR_2005data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NOR_2005data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NOR_2009data<-subset(bvm, cnty=="NOR_2009")
NOR_2009data <-na.omit(NOR_2009data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NOR_2009data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NZL_1996data<-subset(bvm, cnty=="NZL_1996")
NZL_1996data <-na.omit(NZL_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NZL_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NZL_2002data<-subset(bvm, cnty=="NZL_2002")
NZL_2002data <-na.omit(NZL_2002data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NZL_2002data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NZL_2008data<-subset(bvm, cnty=="NZL_2008")
NZL_2008data <-na.omit(NZL_2008data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NZL_2008data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

NZL_2011data<-subset(bvm, cnty=="NZL_2011")
NZL_2011data <-na.omit(NZL_2011data)
m.out<-matchit(treat ~ income + education + age + ideology, data =NZL_2011data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

PER_2000data<-subset(bvm, cnty=="PER_2000")
PER_2000data <-na.omit(PER_2000data)
m.out<-matchit(treat ~ income + education + age + ideology, data =PER_2000data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

PER_2001data<-subset(bvm, cnty=="PER_2001")
PER_2001data <-na.omit(PER_2001data)
m.out<-matchit(treat ~ income + education + age + ideology, data =PER_2001data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

PER_2006data<-subset(bvm, cnty=="PER_2006")
PER_2006data <-na.omit(PER_2006data)
m.out<-matchit(treat ~ income + education + age + ideology, data =PER_2006data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

PHL_2004data<-subset(bvm, cnty=="PHL_2004")
PHL_2004data <-na.omit(PHL_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =PHL_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

POL_1997data<-subset(bvm, cnty=="POL_1997")
POL_1997data <-na.omit(POL_1997data)
m.out<-matchit(treat ~ income + education + age + ideology, data =POL_1997data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

POL_2001data<-subset(bvm, cnty=="POL_2001")
POL_2001data <-na.omit(POL_2001data)
m.out<-matchit(treat ~ income + education + age + ideology, data =POL_2001data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

POL_2005data<-subset(bvm, cnty=="POL_2005")
POL_2005data <-na.omit(POL_2005data)
m.out<-matchit(treat ~ income + education + age + ideology, data =POL_2005data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

POL_2007data<-subset(bvm, cnty=="POL_2007")
POL_2007data <-na.omit(POL_2007data)
m.out<-matchit(treat ~ income + education + age + ideology, data =POL_2007data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

PRT_2002data<-subset(bvm, cnty=="PRT_2002")
PRT_2002data <-na.omit(PRT_2002data)
m.out<-matchit(treat ~ income + education + age + ideology, data =PRT_2002data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

PRT_2005data<-subset(bvm, cnty=="PRT_2005")
PRT_2005data <-na.omit(PRT_2005data)
m.out<-matchit(treat ~ income + education + age + ideology, data =PRT_2005data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

PRT_2009data<-subset(bvm, cnty=="PRT_2009")
PRT_2009data <-na.omit(PRT_2009data)
m.out<-matchit(treat ~ income + education + age + ideology, data =PRT_2009data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ROM_2009data<-subset(bvm, cnty=="ROM_2009")
ROM_2009data <-na.omit(ROM_2009data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ROM_2009data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ROU_1996data<-subset(bvm, cnty=="ROU_1996")
ROU_1996data <-na.omit(ROU_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ROU_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

RUS_2004data<-subset(bvm, cnty=="RUS_2004")
RUS_2004data <-na.omit(RUS_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =RUS_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SRB_2012data<-subset(bvm, cnty=="SRB_2012")
SRB_2012data <-na.omit(SRB_2012data)
m.out<-matchit(treat ~ income + education + age + ideology, data =SRB_2012data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SVK_2010data<-subset(bvm, cnty=="SVK_2010")
SVK_2010data <-na.omit(SVK_2010data)
m.out<-matchit(treat ~ income + education + age + ideology, data =SVK_2010data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SVN_1996data<-subset(bvm, cnty=="SVN_1996")
SVN_1996data <-na.omit(SVN_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =SVN_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SVN_2004data<-subset(bvm, cnty=="SVN_2004")
SVN_2004data <-na.omit(SVN_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =SVN_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SVN_2008data<-subset(bvm, cnty=="SVN_2008")
SVN_2008data <-na.omit(SVN_2008data)
m.out<-matchit(treat ~ income + education + age + ideology, data =SVN_2008data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SWE_1998data<-subset(bvm, cnty=="SWE_1998")
SWE_1998data <-na.omit(SWE_1998data)
m.out<-matchit(treat ~ income + education + age + ideology, data =SWE_1998data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SWE_2002data<-subset(bvm, cnty=="SWE_2002")
SWE_2002data <-na.omit(SWE_2002data)
m.out<-matchit(treat ~ income + education + age + ideology, data =SWE_2002data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

SWE_2006data<-subset(bvm, cnty=="SWE_2006")
SWE_2006data <-na.omit(SWE_2006data)
m.out<-matchit(treat ~ income + education + age + ideology, data =SWE_2006data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

TUR_2011data<-subset(bvm, cnty=="TUR_2011")
TUR_2011data <-na.omit(TUR_2011data)
m.out<-matchit(treat ~ income + education + age + ideology, data =TUR_2011data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

UKR_1998data<-subset(bvm, cnty=="UKR_1998")
UKR_1998data <-na.omit(UKR_1998data)
m.out<-matchit(treat ~ income + education + age + ideology, data =UKR_1998data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

USA_1996data<-subset(bvm, cnty=="USA_1996")
USA_1996data <-na.omit(USA_1996data)
m.out<-matchit(treat ~ income + education + age + ideology, data =USA_1996data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

USA_2004data<-subset(bvm, cnty=="USA_2004")
USA_2004data <-na.omit(USA_2004data)
m.out<-matchit(treat ~ income + education + age + ideology, data =USA_2004data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

USA_2008data<-subset(bvm, cnty=="USA_2008")
USA_2008data <-na.omit(USA_2008data)
m.out<-matchit(treat ~ income + education + age + ideology, data =USA_2008data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

ZAF_2009data<-subset(bvm, cnty=="ZAF_2009")
ZAF_2009data <-na.omit(ZAF_2009data)
m.out<-matchit(treat ~ income + education + age + ideology, data =ZAF_2009data, method="exact")
m.data<-match.data(m.out)
m.out
z.out<-zelig(leftvote ~ treat + income + education + age + ideology, data = m.data, model="logit")
x.out<-setx(z.out, treat=0)
x1.out<-setx(z.out, treat=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)
















#####################
# MATCHING ANALYSIS #
#####################

### AUSTRALIA

# looks like all covariates are populated with values
summary(AUS_1996data) 

# we lose 66 "treated" individuals 
AUS_1996data<-na.omit(AUS_1996data)
m.out<-matchit(treatment ~ age + income + gender + education + ideology + union, data =AUS_1996data, method="exact")
summary(m.out)

# run the analysis on expansion rhetoric
m.data<-match.data(m.out)
z.out<-zelig(as.numeric(left2) ~ treatment + age + income + gender + education + ideology + union , data = m.data, model="ls")

# check out the treatment effect
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

# run the analysis on leftist vote choice
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + age + income + gender + education + ideology + union , data = m.data, model="logit")

# check out the treatment effect
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)


### SPAIN .... there are problems here with missingness 

# looks like all covariates are populated with values
summary(ESP_2000data) 

# we lose 66 "treated" individuals 
ESP_2000data<-na.omit(ESP_2000data)
m.out<-matchit(treatment ~ age + income + gender + education + ideology + union, data =ESP_2000data, method="exact")
summary(m.out)

# run the analysis on expansion rhetoric
m.data<-match.data(m.out)
z.out<-zelig(as.numeric(left2) ~ treatment + age + income + gender + education + ideology + union , data = m.data, model="ls")

# check out the treatment effect
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)

# run the analysis on leftist vote choice
m.data<-match.data(m.out)
z.out<-zelig(left1 ~ treatment + age + income + gender + education + ideology + union , data = m.data, model="logit")

# check out the treatment effect
x.out<-setx(z.out, treatment=0)
x1.out<-setx(z.out, treatment=1)
s.out<-sim(z.out, x=x.out, x1=x1.out, num=10000)
summary(s.out)



